/*
    Copyright (C) 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef ECHARTMARKERS_H
#define ECHARTMARKERS_H

#include "echarts.h"

class EChartMarkersConfig;

#include <QPoint>
#include <QColor>
#include <QPointer>

class QPainter;

/**
	* @brief Class with static functions to draw different markers.
	* @ingroup Charts
	*
	* Use config() to get an object to configure the appearance.
	* The markers are drawn in the current color of the painter.
	* Therefore change it before calling one of the static functions.
	*/
class E_CHARTS_EXPORT EChartMarkers
{
	public:
		EChartMarkers();
		/**
			* @brief Call this function to set and/or get the globel MarkersConfig object.
			*/
		static EChartMarkersConfig *config();

		static void circle(QPainter *painter, QPoint point);
		static void rhomb(QPainter *painter, QPoint point);
		static void square(QPainter *painter, QPoint point);
		static void triangleUp(QPainter *painter, QPoint point);
		static void triangleLeft(QPainter *painter, QPoint point);
		static void triangleBottom(QPainter *painter, QPoint point);
		static void triangleRight(QPainter *painter, QPoint point);

	private:
		uint size() const;
		int halfSize() const;
		void triangle(QPainter *painter, QPoint point, int angle);
		/**
			* @brief The pointer to the config, used by Markers.
			*
			* If some of the static functions from Markers are called
			* before Markers::config() is called, a default MarkersConfig
			* is created.
			*/
		static QPointer<EChartMarkersConfig> markersConfig;
};



#endif // ECHARTMARKERS_H
