/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EABOUTPERSON_H
#define EABOUTPERSON_H

#include "eglobal.h"
#include "eobject.h"

/**
	* @brief A person, which should be mentioned at the EAboutDialog.
	*
	*/
class E_CORE_EXPORT EAboutPerson : public EObject
{
	Q_OBJECT
	Q_FLAGS(Categories)
	public:
		/**
			* @brief Identifies, what the person has done.
			*
			* This Categories are or combineable, so one person can
			* be honored as an translator, author and ...
			*/
		enum Category {
			Author 			= 0x01,	/**< The person has contributed amount of source code. */
			Translator 	= 0x02,	/**< The person has translated the application. */
			Thanks 			= 0x04 	/**< The person has contributed something and should be mentioned,
														* but no other category matches his contributions.
														*/
		};
		Q_DECLARE_FLAGS(Categories, Category)
		Q_ENUMS(Category)
		
		EAboutPerson(QString name, QString givenName, Categories categories,	 QObject *parent = 0);
		EAboutPerson(QString name, QString givenName, QString email, Categories categories,	 QObject *parent = 0);
		void setName(QString name);
		QString name() const;
		void setGivenName(QString givenName);
		QString givenName() const;
		void setEmail(QString address);
		QString email() const;
		void setCategories(Categories categories);
		Categories categories() const;
		
	private:
		QString myName, myGivenName, myMail;
		Categories myCats;
};

Q_DECLARE_OPERATORS_FOR_FLAGS(EAboutPerson::Categories)

#endif // EABOUTPERSON_H