/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EACTION_H
#define EACTION_H

#include "eglobal.h"

#include <QAction>

#include <QPointer>

/**
	* @brief QAction replacement, which handles "iconsAndText"-option and QIcon::fromTheme.
	*
	* To get an action which has enabled the text in any cases, call actionWithText(). This can be useful,
	* if this action should be used in a QToolBar (only icons) and in a context menu (Text needed in any case).
	*
	* @see EPushButton
	*/
class E_CORE_EXPORT EAction : public QAction
{
	Q_OBJECT
	/**
		* if set to true, the text will be shown in any case
		* if set to false (default), the text will only be shown, if no icon is set
		* or iconsAndText is true
		*/
	Q_PROPERTY(bool showText READ showText WRITE setShowText)
	public:
		/**
			* Creates an action and tries to set the icon to the @p standardIconName. If this is not possible (due to unsupported Qt Version
			* or their is no standard icon, it uses @p iconPath to load icon from resource. It also sets the text to @p text.
			* Further on, if @p enableText is set to true, text is shown anytime and iconsAndText is ignored.
			*/
		EAction ( QString standardIconName, QString iconPath,  const QString & text, QObject * parent = 0, bool enableText = false );
		EAction ( const QString & text, QObject * parent = 0 );
		~EAction();
		/**
			* @returns If the returned action is triggered, this action emit the triggered signal too!
			*   The returned action is alse enabled or disabled when this action is enabled or disabled.
			*   Shortly, this action takes care of the returned action and you must not handle it.
			*   Epsecially, don't delete the returned action, this Action will do it.
			*/
		QAction *actionWithText();
		void setText ( const QString & text );
		void setIcon(const QIcon& icon);
		void setIcon(QString standardIconName, QString iconPath );
		/**
			* @brief Determines, if the text is hidden (Default), when an icon is there or not.
			*/
		void setShowText(bool anytime = true);
		bool showText() const;
	
	public slots:
		void setEnabled ( bool status );
		void setDisabled ( bool status );
		
	private slots:
		void triggeredByPass();
		
	private:
		void init(bool enableText);
		
		QString myText;
		bool iconsAndText, myShowText;
		QPointer<QAction> myActionWithText;
};

#endif // EACTION_H
