/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EDBBACKUP_H
#define EDBBACKUP_H

#include "eglobal.h"
#include "esetupwizardwidget.h"

namespace Ui {
	class EDBBackup;
}

#include <QFileInfo>
#include <QTextStream>

/**
  * @brief ESetupWizardObject to dump SQL databases into a file.
	* @ingroup SQL
  *
  * If you need a dialog around it, use EDBBackupDialog instead.
  */
class E_CORE_EXPORT EDBBackup : public ESetupWizardWidget
{
	Q_OBJECT
	public:
		EDBBackup(ESetupWizardObject *newObject, QWidget *parent = NULL, Qt::WindowFlags flags = 0);
		~EDBBackup();
		
		static QString mysqlEscape(QString input);
		
		/**
		  * @brief Returns true, if a database dump is running.
		  *
		  * If you want to stop it, call abort(). If finished, this function
		  * is returns false again and signal exportFinished(bool) is emitted.
		  */
		bool working() const;
		
	public slots:
		bool finish();
    bool saveSettings(QString &error);
		void abort();
		
	private slots:
		void setDumpFile();
		
	private:
		/**
			* dump the sql create statement and the content of the @p table to  @p stream
			* @return true if all is done correctly and false if an error occurs
			*/
		bool dumpTable ( QString table, QTextStream &stream);
		/**
			* we must insert them in correct order, because some need other views
			*/
		bool dumpView ( QString view, QTextStream &stream);
		QStringList sortViews(QStringList views);
		void setRange ( int num );
    void finishedStep();
    void actualStep ( QString msg );
    void log ( QString msg );
		
		QFileInfo dumpFile;
		QString codecName;
		bool doAbort, isWorking;
		Ui::EDBBackup *ui;
		
	signals:
		void exportStarted();
		void exportFinished(bool result);
};

#endif // EDBBACKUP_H
