/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EDBSETTINGS_H
#define EDBSETTINGS_H

#include "eglobal.h"
#include "esetupwizardwidget.h"

namespace Ui {
	class EDBSettings;
}

/**
	* @brief This class is used to let the user enter some settings related to the database.
	* @ingroup SQL
	*
	* The widget is displayed at two places. First it is used at the @see SetupWizard and second
	* at the @see SettingsDialog.
	* The Part of creating database and user is only displayed, if the SetupWizardObject
	* at the constructor is not null.
	*
	* @todo use EDBSettingsWidget to enter the basic database settings.
	*/
class E_CORE_EXPORT EDBSettings : public ESetupWizardWidget
{
	Q_OBJECT
  public:
		/**
			* You can specify which database drivers are displayed at the dropdown box with
			* @p drivers. If nothing is specified, it uses QSqlDatabase::drivers().
			* if @p newObject is null, the createDatabaseBox is hidden, because the widget runs in
			* @see SettingsDialog mode.
			*/
		EDBSettings ( QStringList drivers = QStringList(), ESetupWizardObject *newObject = 0, QWidget *parent = 0, Qt::WindowFlags fl = 0 );
    ~EDBSettings();

  public slots:
		/**
			* if create database and/or create user is chosen,
			* this function executes needed commands.
			* it assumes, that the user has the privileges to use the database,
			* if he only select create database
			*/
    bool finish();
    bool saveSettings(QString& error);
		void reloadSettings();

	private:
		Ui::EDBSettings *ui;
};

#endif // EDBSETTINGS_H
