/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef DELEGATEFOREIGNKEY_H
#define DELEGATEFOREIGNKEY_H

#include "eglobal.h"

#include <QStyledItemDelegate>

#include <QPainter>

class QSqlQueryModel;
class QTimer;

/**
  * @brief A delegate to display and edit foreign keys from SQL tables.
	*
	* If there are more than maxComboItems, it switches to QLineEdit with autocompletion
	* if there are more than maxCompleteItems, it loads the completer after 3 inserted characters to reduce load.
	*
	* To translate the mapped function, set the translator callback to an apropriate function with setTranslator() or the related constructor.
	*
	* @todo last one is not useable right now
	* @todo use ESqlDatabase if it is available
	* @todo The completer model does not support translations yet
  */
class E_CORE_EXPORT EDelegateForeignKey : public QStyledItemDelegate{
  Q_OBJECT
  public:
    /**
      * @param table the table where the foreignkey points to
      * @param matchColumn the column which is the same in showed table and foreignkey table (at table @p table)
      * @param resultColumn the column at the foreignkey table which holds the content to be displayed
			*
			* @see EDelegateForeignKey(QString, QString, QString, QString (*)(const QString), QWidget*)
      */
    EDelegateForeignKey(QString table, QString matchColumn, QString resultColumn, QWidget *parent = 0);
		/**
			* @brief Constructor to supply an translator callback.
			*
			* @see EDelegateForeignKey(QString, QString, QString, QWidget*)
			*/
		EDelegateForeignKey(QString table, QString matchColumn, QString resultColumn, QString (*translator)(const QString), QWidget *parent = 0);
		void setTranslator(QString (*translator)(const QString));
		void reloadForeignKeys();

		/**
			* @todo must be really improved to use QCompleter with only part of the table (useExtendedCompleter)
			*/
    void paint(QPainter *painter, const QStyleOptionViewItem &option,
            const QModelIndex &index) const;
    QWidget *createEditor(QWidget* parent, const QStyleOptionViewItem&, const QModelIndex&) const;
    void setEditorData(QWidget *editor, const QModelIndex &index) const;
    void setModelData(QWidget *editor, QAbstractItemModel *model,
                   const QModelIndex &index) const;

  private slots:
    void commitAndCloseEditor();
		void doCloseEditor();
		/**
			* @todo must be really improved
			*/
		void updateCompleter();
// 		void doAddPair(QString key, unsigned int value);

  private:
		void init(QString table, QString matchColumn, QString resultColumn);
		/**
			* the QString, int order is needed,
			* because the entries should be ordered after the string's
			*/
    QMap<QString, unsigned int> mapOutIn;
    QString resTable, matchCol, resCol;
		QSqlQueryModel *resultModel;
		int maxComboItems, maxCompleteItems;
		bool useComboBox, useCompleter, useExtendedCompleter;
		QTimer *timer;
		/**
			* Function callback to translate QString into QString.
			*/
		QString (*translator)(const QString);
		
	signals:
// 		void addPair(QString key, unsigned int value);
};

#endif // DELEGATEFOREIGNKEY_H
