/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EFILEDIALOG_H
#define EFILEDIALOG_H

#include "eglobal.h"
#include "eobject.h"

#include <QFileDialog>

/**
	* @brief EFileDialog provides a convient API to use a filedialog. EFileDialog
	*				 uses KFileDialog if possible, otherwise it uses QFileDialog as a fallback
	*
	* EFileDialog uses QFileDialog as fallback Filedialog. If compiled with KDE,
	* it uses KFileDialog automatically and converts the filters correctly.
	* You should call it like QFileDialog functions and also the filters and all
	* other stuff is used like QFileDialog uses it. All needed conversions to KDE
	* API are done within this class automatically.
	*/
class E_CORE_EXPORT EFileDialog : public EObject
{
	Q_OBJECT
	public:
		static QString   getExistingDirectory ( QWidget * parent = 0, const QString & caption = QString(),
																		 const QString & dir = QString(),
																		 QFileDialog::Options options = QFileDialog::ShowDirsOnly );
		static QString   getOpenFileName ( QWidget * parent = 0, const QString & caption = QString(),
																const QString & dir = QString(), const QString & filter = QString(),
																QString * selectedFilter = 0, QFileDialog::Options options = 0 );
		static QStringList   getOpenFileNames ( QWidget * parent = 0, const QString & caption = QString(),
																		 const QString & dir = QString(), const QString & filter = QString(),
																		 QString * selectedFilter = 0, QFileDialog::Options options = 0 );
		static QString   getSaveFileName ( QWidget * parent = 0, const QString & caption = QString(),
																const QString & dir = QString(), const QString & filter = QString(),
																QString * selectedFilter = 0, QFileDialog::Options options = 0 );
};

#endif // EFILEDIALOG_H
