/*
    Copyright (C) 2011 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EFILESERVICEPLUGIN_H
#define EFILESERVICEPLUGIN_H

#include "eobject.h"
#include "eglobal.h"

class EFileInfo;
class ESettingsWidget;

class QFileInfo;

/**
	* @brief A plugin used by EFileService to handle special file system types.
	* 
	* E.g. you can store the files in a database or an application server.
	*/
class E_CORE_EXPORT EFileServicePlugin : public EObject
{
	public:
		virtual ~EFileServicePlugin() {}
		
		virtual QString name() const = 0;
		virtual QString serviceId() const = 0;
		
		virtual EFileInfo info(QString uniqueId) const = 0;
		/**
			* @brief Adds file described by @p info to the handled files.
			* 
			* If @p create is set to true, the file should be created,
			* if it does not exists already.
			* 
			* Adding as is can mean, add a local file to an repository
			* or to a remote file system or something else.
			* In the case of the EFileSystemPlugin, this functions only
			* converts the QFileInfo into an EFileInfo, because the files
			* are the physically the same.
			*/
		virtual EFileInfo add(QFileInfo info, bool create) const = 0;
		/**
			* @brief Moves the file from @p source to @p target.
			* 
			* @p target should be an absolute file path.
			* @see copy() to copy @p source.
			*/
		virtual bool move(EFileInfo source, QString target) const = 0;
		/**
			* @brief Copies the file from @p source to @p target.
			* 
			* @p target should be an absolute file path.
			* @see move() to move @p source.
			*/
		virtual bool copy(EFileInfo source, QString target) const = 0;
		virtual bool deleteFile(EFileInfo file) const = 0;
		/**
			* @brief Open the given @p file.
			* 
			* If the file must be prepared before it can be opened
			* (like the file must be downloaded first), do such actions
			* in a seperate thread in background. Just
			* start these action and return true here to not freeze the GUI.
			* To open the file, please use EOpenFileExternal::openFile(QString, QString, QObject*).
			*/
		virtual bool open(EFileInfo file) = 0;
		virtual ESettingsWidget* settingsWidget() const = 0;
};

#if QT_VERSION >= 0x050000
#define LibEngsasEfileServicePluginIID "de.engsas.libengsas.EFileServicePlugin"
Q_DECLARE_INTERFACE(EFileServicePlugin, LibEngsasEfileServicePluginIID)
#else
Q_DECLARE_INTERFACE ( EFileServicePlugin, "LibEngsas.EFileServicePlugin/0.1.0" );
#endif

#endif // EFILESERVICEPLUGIN_H
