/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/


#ifndef EHELPCENTER_H
#define EHELPCENTER_H

#include "eobject.h"
#include "eglobal.h"

#include "ehelpcentersetup.h"

class QProcess;

/**
	* @brief Manage the QtAssistant usage to display the online help.
	*
	* It starts QtAssistant and tries to load the given documentation collection.
	* A specific page inside the documentation collection can be shown with showDocumentation()
	*/
class E_CORE_EXPORT EHelpCenter : public EObject
{
	Q_OBJECT
	public:
		EHelpCenter(EHelpCenterSetup setup, QObject *parent);
		~EHelpCenter();
		
	public slots:
		/**
			* @param page if page starts with keyword: then a the part after : is used as a keyword
			*/
		void showDocumentation( QString page = QString());
		
	private:
		/**
			* @brief Returns a file of @p files for current language.
			*
			* If no file for current language is found, the english version
			* is returned. If that version is also not found, an empty
			* string is returned.
			*/
		QString fileForLang(QStringList files);
		
		bool startAssistant();
		QProcess *assistantProcess;
		EHelpCenterSetup settings;
		QFileInfo qhcFile;
		QList<QFileInfo> qchFiles;
};

#endif // EHELPCENTER_H
