/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef EMODULELISTWIDGETITEM_H
#define EMODULELISTWIDGETITEM_H

#include "eglobal.h"

#include <QListWidgetItem>
#include <QFileInfo>

/**
	* @brief A QListWidgetItem to handle information about a plugin.
	*
	* The extended QListWidgetItem is used to handle information
	* about a plugin. It contains the information:
	* @li The name of the module (if loaded)
	* @li The related file
	* @li The status of the load
	* @li An error message, what went wrong during the load
	* @li An description of the module
	* @li The icon of the module.
	*
	* But be aware, that the name, description and icon is extraced
	* via extractFromPlugin(), which uses the QObject::property() to
	* get this values.
	* 
	*/
class E_CORE_EXPORT EModuleListWidgetItem : public QListWidgetItem
{
	public:
    EModuleListWidgetItem ( QObject *plugin, QListWidget* parent = 0, int type = Type);
    EModuleListWidgetItem ( QListWidget *parent = 0, int type = Type );
    EModuleListWidgetItem ( QString text, QListWidget * parent = 0, int type = Type );
    EModuleListWidgetItem ( QIcon icon, QString text, QListWidget *parent = 0, int type = Type );

	QObject* plugin() const;
	void setPlugin(QObject *plugin);
    void setName ( QString name );
    QString name() const;
    void setFile ( QString file );
    QString file() const;
    void setStatus ( bool status );
    bool status() const;
    void setErrorMessage ( QString message );
    QString errorMessage() const;
    void setDescription ( QString description );
    QString description() const;
		void setModuleIcon(QImage modIcon);
		QIcon moduleIcon() const;

		/**
			* @brief Extracts some meta data with help of QObject::property().
			*
			* It tries to get some information about the given @p plugin
			* with help of the QObject::property() functioninalities.
			* Therefore your plugin should register the following properties:
			* @li name
			* @li description
			* @li icon
			* 
			* @see EPart
			*/
		void extractFromPlugin(QObject *plugin);
		
		QListWidgetItem *clone() const;
		
		bool operator== (const EModuleListWidgetItem &item) const;
    bool operator!= (const EModuleListWidgetItem &item) const;

  private:
    QFileInfo myFile;
    QString myErrorMessage;
    QString myDescription;
		QImage myModuleIcon;
	QObject *myPlugin;
    bool myStatus;

    void init();
};

#endif // EMODULELISTWIDGETITEM_H
