/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef ESETTINGSMODELITEM_H
#define ESETTINGSMODELITEM_H

#include "eglobal.h"
#include "eobject.h"

class ESettingsWidget;

#include <QString>
#include <QList>

/**
	* @brief An item in the ESettingsModel, which represents one Settingspage.
	*
	*/
class E_CORE_EXPORT ESettingsModelItem : public EObject
{
	Q_OBJECT
	public:
		/**
			* @brief Creates a new Item.
			*
			* The name of the new item is set to @p name. The parent will be @p parent and the related
			* settings widget is @p widget.
			*/
		ESettingsModelItem(QString name, ESettingsWidget *widget, ESettingsModelItem *parent = 0);
		/**
			* @brief Creates a new item from @p widget.
			*/
		ESettingsModelItem(ESettingsWidget *widget, ESettingsModelItem *parent = 0);
		~ESettingsModelItem();

		void setName(QString name);
		/**
			* @brief Returns the name of the item.
			*/
		QString name() const;
		void setWidget(ESettingsWidget *widget);
		/**
			* @brief Returns a pointer to the widget of this item.
			*
			* The pointer can be a NULL-Pointer, if no widget is related to this item (like Category only items)
			*/
		ESettingsWidget* widget() const;

		void setParent(ESettingsModelItem *parent);
		/**
			* @brief Returns a pointer to the parent item.
			*
			* If NULL-Pointer is returned, it is the root item.
			*/
		ESettingsModelItem* parent() const;
		/**
			* @brief Adds child @p item to the list of childs.
			*
			* Set's also the parent of @p item to this.
			*/
		void addChild(ESettingsModelItem *item);
		/**
			* @brief Overloaded function for addChild(ESettingsModelItem*).
			*/
		void addChild(ESettingsWidget *widget);
		/**
			* @brief Returns a pointer to child at position @p row.
			*
			* Can be NULL-Pointer, if @p row is smaller than 0 or greater then rowCount().
			*/
		ESettingsModelItem* child(int row) const;
		/**
			* @brief Returns the row of the item @p child.
			*
			*/
		int childRow(ESettingsModelItem* child) const;
		/**
			* @brief Returns the number of childrens of this item.
			*/
		int rowCount() const;
		bool save(QString &error);

	private slots:
		inline void reloadSettingsRequestByPass(){ emit reloadSettingsRequest(); };
		
	private:
		ESettingsModelItem *myParent;
		QList<ESettingsModelItem*> myChilds;
		QString myName;
		ESettingsWidget *myWidget;
};

#endif // ESETTINGSMODELITEM_H
