/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef ESQLFIELD_H
#define ESQLFIELD_H

#include "eglobal.h"
#include "eobject.h"

#include <QString>
#include <QVariant>
#include <QMultiHash>

/**
	* @brief Represents an field in an sql table.
	* @ingroup SQL
	*
	* This class is used with ESqlInit to define database schemas.
	*
	* @see ESqlTable
	* @see ESqlInit
	*/
class E_CORE_EXPORT ESqlField : public EObject
{
	Q_OBJECT
  public:
    enum Type { NoType, Integer, Text, Varchar, Boolean, Date, Time, Tinyint, Double, Timestamp, Blob, LongBlob };

    ESqlField(QObject* parent = 0);
    ESqlField ( QString myName, ESqlField::Type myType = ESqlField::NoType, bool notNull = false, bool autoIncrement = false, QObject* parent = 0 );
    bool isValid() const;
    QString name() const;
    void setName ( QString myName );
    bool isPrimaryKey() const;
    void setIsPrimaryKey ( bool status );
    bool autoIncrement() const;
    void setAutoIncrement ( bool status );
    bool notNull() const;
    void setNotNull ( bool status );
    QVariant defaultValue() const;
    void setDefaultValue ( QVariant value );
    ESqlField::Type dataType() const;
    void setDataType ( ESqlField::Type myType );
    unsigned int length() const;
    void setLength ( unsigned int len );
    bool isUnsigned() const;
    void setIsUnsigned ( bool status );
    bool isBinary() const;
    void setIsBinary ( bool status );
    bool zeroFill() const;
    void setZeroFill ( bool status );
    QString sqlFieldType() const;
		 /**
      * @brief Creates the SQL statement to create the field.
			*
      * e.g. a field with name cell2 and varchar(20) not null
      * will result in this statement:
      * cell2 varchar(20) not null
      */
		QString createStatement( EngSaS::SQL::DatabaseType type);
		
		ESqlField *copy() const;
		
		bool operator== (const ESqlField &field) const;
		bool operator!= (const ESqlField &field) const;

  private:
    QString fieldName;
    bool pk;
    bool ai;
    bool nn;
    QVariant fieldDefValue;
    ESqlField::Type fieldType;
    unsigned int fieldLength;
    bool binary;
    bool fieldUnsigned;
    bool zf;
    QMultiHash<int, QString> convFieldTypes;

    void init();
};

#endif // ESQLFIELD_H
