/*
    Copyright (C) 2010 - 2012 EngSaS - Engineering Solutions and Services Langenbach. All rights reserved.

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    MA 02110-1301  USA.
*/

#ifndef ETABLEVIEW_H
#define ETABLEVIEW_H

#include "eglobal.h"

#include <QTableView>

/**
	* @brief An improved Replacement for QTableView.
	*
	* It removes and deletes all remaining delegates from a previous used model.
	*/
class E_CORE_EXPORT ETableView : public QTableView
{
	Q_OBJECT
	public:
		ETableView(QWidget *parent = 0);
		void setModel(QAbstractItemModel* model);
		void reloadDelegates();
		/**
			* @attention it uses the columnCount() of the current model to walk through all columns, therefore call it before the model is reseted!
			*/
		void deleteDelegates();
		/**
		  * @brief Resize all columns to their content and the afterwards available space is given to @p expandingColumn.
		  */
		void resizeAndHideColumns(QList<int> hideColumns, int expandingColumn);
};

#endif // ETABLEVIEW_H
